@@ -8,10 +8,9 @@ predict.cv.hqreg <- function(object, X, lambda = c("lambda.1se","lambda.min"), t
 }
 
 coef.cv.hqreg <- function(object, lambda = c("lambda.1se","lambda.min"), ...) {
-  type = match.arg(type)
   if (is.character(lambda)) {
     lambda = match.arg(lambda)
     lambda = object[[lambda]]
   } else if(!is.numeric(lambda)) stop("Invalid lambda")
-  coef(object$fit, lambda = lambda, type = type, ...)
-}
\ No newline at end of file
+  coef(object$fit, lambda = lambda, ...)
+}
